pub struct Chain<R1: Read, R2: Read> { /* private fields */ }Expand description
Adapter to chain two readers together.
It might seem the exact same as std::io::Chain but it
is not. The difference is that when it reaches the end of
the first reader, it fills the rest of the buffer with
the first bytes from the second reader, what std::io::Chain
doesn’t do.
Implementations